from pathlib import Path
import yaml
from yaml.loader import SafeLoader
import os
import logging
from kwhmeter import data_dir

kwhmeter_pvpc_config=f'{data_dir}/kwhmeter_pvpc_config.yml'

if os.path.exists(kwhmeter_pvpc_config):
    with open(kwhmeter_pvpc_config) as f:
        config_pvpc = yaml.load(f, Loader=SafeLoader)
else:
    import pkg_resources
    logging.warning(f"{kwhmeter_pvpc_config} do not exists. Using default one")
    with pkg_resources.resource_stream(__name__, 'data/kwhmeter_pvpc_config.yml') as f:
        config_pvpc = yaml.load(f, Loader=SafeLoader)
    with open(kwhmeter_pvpc_config,'w') as f:                    
        f.write(yaml.dump(config_pvpc))

kwhmeter_influxDB_config=f'{data_dir}/kwhmeter_influxDB_config.yml'

if os.path.exists(kwhmeter_influxDB_config):
    with open(kwhmeter_influxDB_config) as f:
        config_export2 = yaml.load(f, Loader=SafeLoader)
else:
    import pkg_resources
    logging.warning(f"{kwhmeter_influxDB_config} do not exists. Using default one")
    with pkg_resources.resource_stream(__name__, 'data/kwhmeter_influxDB_config.yml') as f:
        config_export2 = yaml.load(f, Loader=SafeLoader)
    with open(kwhmeter_influxDB_config,'w') as f:                    
        f.write(yaml.dump(config_export2))        


from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="kwhmeter_utils",
    version_config=True,
    setup_requires=['setuptools-git-versioning'],
    author="nachomas",
    author_email="mas.ignacio@gmail.com",
    description="Simulador de facturas PVPC",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/nachoplus/kwhmeter_utils",
    packages=find_packages(),
    package_data={'': ['data/*.yml']},    
    install_requires=[
        'kwhmeter',
        'pandas',
        'influxdb'
    ],
    extras_require={

    },
    setuptools_git_versioning={
        "enabled": True,
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
